# Encoder


::: linax.encoder.base.EncoderConfig
    options:
        members:
            - build

---

::: linax.encoder.base.Encoder
    options:
        members:
            - __init__
            - __call__
